@@ -17,7 +17,11 @@
 # limitations under the License.                                           #
 ############################################################################
 import os
+import sys
+
+__version__ = "0.12.1"
 
 IS_WIN = os.name == 'nt'
+IS_PYODIDE = 'pyodide' in sys.modules
 
 pygls = 'pygls'
