@@ -20,11 +20,10 @@ import logging
 import re
 import sys
 from concurrent.futures import Future, ThreadPoolExecutor
-from multiprocessing.pool import ThreadPool
 from threading import Event
 from typing import Any, Callable, List, Optional, TypeVar
 
-from pygls import IS_WIN
+from pygls import IS_WIN, IS_PYODIDE
 from pygls.lsp.types import (ApplyWorkspaceEditResponse, ClientCapabilities, ConfigCallbackType,
                              ConfigurationParams, Diagnostic, MessageType, RegistrationParams,
                              ServerCapabilities, TextDocumentSyncKind, UnregistrationParams,
@@ -34,6 +33,10 @@ from pygls.progress import Progress
 from pygls.protocol import LanguageServerProtocol, deserialize_message
 from pygls.workspace import Workspace
 
+if not IS_PYODIDE:
+    from multiprocessing.pool import ThreadPool
+
+
 logger = logging.getLogger(__name__)
 
 F = TypeVar('F', bound=Callable)
@@ -98,6 +101,23 @@ class StdOutTransportAdapter:
         self.wfile.flush()
 
 
+class PyodideTransportAdapter:
+    """Protocol adapter which overrides write method.
+
+    Write method sends data to stdout.
+    """
+
+    def __init__(self, wfile):
+        self.wfile = wfile
+
+    def close(self):
+        self.wfile.close()
+
+    def write(self, data):
+        self.wfile.write(data)
+        self.wfile.flush()
+
+
 class WebSocketTransportAdapter:
     """Protocol adapter which calls write method.
 
@@ -159,13 +179,14 @@ class Server:
 
         if IS_WIN:
             asyncio.set_event_loop(asyncio.ProactorEventLoop())
-        else:
+        elif not IS_PYODIDE:
             asyncio.set_event_loop(asyncio.SelectorEventLoop())
 
-        self.loop = loop or asyncio.get_event_loop()
+        self.loop = loop or asyncio.new_event_loop()
 
         try:
-            asyncio.get_child_watcher().attach_loop(self.loop)
+            if not IS_PYODIDE:
+                asyncio.get_child_watcher().attach_loop(self.loop)
         except NotImplementedError:
             pass
 
@@ -214,6 +235,16 @@ class Server:
         finally:
             self.shutdown()
 
+    def start_pyodide(self):
+
+        logger.info('Starting Pyodide server')
+
+        # Note: We don't actually start anything running as the main event
+        # loop will be handled by the web platform.
+        transport = PyodideTransportAdapter(sys.stdout)
+        self.lsp.connection_made(transport)
+        self.lsp._send_only_body = True  # Don't send headers within the payload
+
     def start_tcp(self, host, port):
         """Starts TCP server."""
         logger.info('Starting TCP server on %s:%s', host, port)
@@ -262,22 +293,24 @@ class Server:
             self._stop_event.set()
             self.shutdown()
 
-    @property
-    def thread_pool(self) -> ThreadPool:
-        """Returns thread pool instance (lazy initialization)."""
-        if not self._thread_pool:
-            self._thread_pool = ThreadPool(processes=self._max_workers)
+    if not IS_PYODIDE:
 
-        return self._thread_pool
+        @property
+        def thread_pool(self) -> ThreadPool:
+            """Returns thread pool instance (lazy initialization)."""
+            if not self._thread_pool:
+                self._thread_pool = ThreadPool(processes=self._max_workers)
 
-    @property
-    def thread_pool_executor(self) -> ThreadPoolExecutor:
-        """Returns thread pool instance (lazy initialization)."""
-        if not self._thread_pool_executor:
-            self._thread_pool_executor = \
-                ThreadPoolExecutor(max_workers=self._max_workers)
+            return self._thread_pool
 
-        return self._thread_pool_executor
+        @property
+        def thread_pool_executor(self) -> ThreadPoolExecutor:
+            """Returns thread pool instance (lazy initialization)."""
+            if not self._thread_pool_executor:
+                self._thread_pool_executor = \
+                    ThreadPoolExecutor(max_workers=self._max_workers)
+
+            return self._thread_pool_executor
 
 
 class LanguageServer(Server):
@@ -322,9 +355,9 @@ class LanguageServer(Server):
         """Decorator used to register LSP features.
 
         Example:
-            @ls.feature('textDocument/completion', triggerCharacters=['.'])
-            def completions(ls, params: CompletionRequest):
-                return CompletionList(False, [CompletionItem("Completion 1")])
+            @ls.feature('textDocument/completion', CompletionOptions(trigger_characters=['.']))
+            def completions(ls, params: CompletionParams):
+                return CompletionList(is_incomplete=False, items=[CompletionItem("Completion 1")])
         """
         return self.lsp.fm.feature(feature_name, options)
 
